package com.xinelu.manage.mapper.batchsendtaskvariableinfo;

import com.xinelu.manage.domain.batchsendtaskvariableinfo.BatchSendTaskVariableInfo;

import java.util.List;

/**
 * 批量推送任务记录变量属性Mapper接口
 *
 * @author zh
 * @date 2026-04-26
 */
public interface BatchSendTaskVariableInfoMapper {
    /**
     * 查询批量推送任务记录变量属性
     *
     * @param id 批量推送任务记录变量属性主键
     * @return 批量推送任务记录变量属性
     */
    BatchSendTaskVariableInfo selectBatchSendTaskVariableInfoById(Long id);

    /**
     * 查询批量推送任务记录变量属性列表
     *
     * @param batchSendTaskVariableInfo 批量推送任务记录变量属性
     * @return 批量推送任务记录变量属性集合
     */
    List<BatchSendTaskVariableInfo> selectBatchSendTaskVariableInfoList(BatchSendTaskVariableInfo batchSendTaskVariableInfo);

    /**
     * 新增批量推送任务记录变量属性
     *
     * @param batchSendTaskVariableInfo 批量推送任务记录变量属性
     * @return 结果
     */
    int insertBatchSendTaskVariableInfo(BatchSendTaskVariableInfo batchSendTaskVariableInfo);

    /**
     * 修改批量推送任务记录变量属性
     *
     * @param batchSendTaskVariableInfo 批量推送任务记录变量属性
     * @return 结果
     */
    int updateBatchSendTaskVariableInfo(BatchSendTaskVariableInfo batchSendTaskVariableInfo);

    /**
     * 删除批量推送任务记录变量属性
     *
     * @param id 批量推送任务记录变量属性主键
     * @return 结果
     */
    int deleteBatchSendTaskVariableInfoById(Long id);

    /**
     * 批量删除批量推送任务记录变量属性
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBatchSendTaskVariableInfoByIds(Long[] ids);

    /**
     * 批量添加变量表
     *
     * @param batchSendTaskVariableInfos 变量信息
     * @return int
     */
    int insertBatchSendTaskVariableInfos(List<BatchSendTaskVariableInfo> batchSendTaskVariableInfos);
}
