package com.xinelu.manage.controller.batchsendtaskvariableinfo;

import com.xinelu.common.annotation.Log;
import com.xinelu.common.core.controller.BaseController;
import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.common.core.page.TableDataInfo;
import com.xinelu.common.enums.BusinessType;
import com.xinelu.common.utils.poi.ExcelUtil;
import com.xinelu.manage.domain.batchsendtaskvariableinfo.BatchSendTaskVariableInfo;
import com.xinelu.manage.service.batchsendtaskvariableinfo.IBatchSendTaskVariableInfoService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 批量推送任务记录变量属性Controller
 *
 * @author zh
 * @date 2026-04-26
 */
@RestController
@RequestMapping("/system/batchSendTaskVariableInfo")
public class BatchSendTaskVariableInfoController extends BaseController {
    @Resource
    private IBatchSendTaskVariableInfoService batchSendTaskVariableInfoService;

    /**
     * 查询批量推送任务记录变量属性列表
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:list')")
    //@GetMapping("/list")
    public TableDataInfo list(BatchSendTaskVariableInfo batchSendTaskVariableInfo) {
        startPage();
        List<BatchSendTaskVariableInfo> list = batchSendTaskVariableInfoService.selectBatchSendTaskVariableInfoList(batchSendTaskVariableInfo);
        return getDataTable(list);
    }

    /**
     * 导出批量推送任务记录变量属性列表
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:export')")
    @Log(title = "批量推送任务记录变量属性", businessType = BusinessType.EXPORT)
    //@PostMapping("/export")
    public void export(HttpServletResponse response, BatchSendTaskVariableInfo batchSendTaskVariableInfo) {
        List<BatchSendTaskVariableInfo> list = batchSendTaskVariableInfoService.selectBatchSendTaskVariableInfoList(batchSendTaskVariableInfo);
        ExcelUtil<BatchSendTaskVariableInfo> util = new ExcelUtil<>(BatchSendTaskVariableInfo.class);
        util.exportExcel(response, list, "批量推送任务记录变量属性数据");
    }

    /**
     * 获取批量推送任务记录变量属性详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:query')")
    //@GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return AjaxResult.success(batchSendTaskVariableInfoService.selectBatchSendTaskVariableInfoById(id));
    }

    /**
     * 新增批量推送任务记录变量属性
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:add')")
    @Log(title = "批量推送任务记录变量属性", businessType = BusinessType.INSERT)
    //@PostMapping
    public AjaxResult add(@RequestBody BatchSendTaskVariableInfo batchSendTaskVariableInfo) {
        return toAjax(batchSendTaskVariableInfoService.insertBatchSendTaskVariableInfo(batchSendTaskVariableInfo));
    }

    /**
     * 修改批量推送任务记录变量属性
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:edit')")
    @Log(title = "批量推送任务记录变量属性", businessType = BusinessType.UPDATE)
    //@PutMapping
    public AjaxResult edit(@RequestBody BatchSendTaskVariableInfo batchSendTaskVariableInfo) {
        return toAjax(batchSendTaskVariableInfoService.updateBatchSendTaskVariableInfo(batchSendTaskVariableInfo));
    }

    /**
     * 删除批量推送任务记录变量属性
     */
    @PreAuthorize("@ss.hasPermi('system:batchSendTaskVariableInfo:remove')")
    @Log(title = "批量推送任务记录变量属性", businessType = BusinessType.DELETE)
    //@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(batchSendTaskVariableInfoService.deleteBatchSendTaskVariableInfoByIds(ids));
    }
}
